nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

I2c

Struct I2c 

pub struct I2c { /* private fields */ }
I2C-bus interfaces

Implementations

Source

impl I2c

pub const unsafe fn from_ptr(ptr: *mut ()) -> Self

pub const fn as_ptr(&self) -> *mut ()

pub const fn cfg(self) -> Reg<Cfg, RW>

Configuration for shared functions.

pub const fn stat(self) -> Reg<Stat, RW>

Status register for Master, Slave, and Monitor functions.

pub const fn intenset(self) -> Reg<Intenset, RW>

Interrupt Enable Set and read register.

pub const fn intenclr(self) -> Reg<Intenclr, W>

Interrupt Enable Clear register.

pub const fn timeout(self) -> Reg<Timeout, RW>

Time-out value register.

pub const fn clkdiv(self) -> Reg<Clkdiv, RW>

Clock pre-divider for the entire I2C interface. This determines what time increments are used for the MSTTIME register, and controls some timing of the Slave function.

pub const fn intstat(self) -> Reg<Intstat, R>

Interrupt Status register for Master, Slave, and Monitor functions.

pub const fn mstctl(self) -> Reg<Mstctl, RW>

Master control register.

pub const fn msttime(self) -> Reg<Msttime, RW>

Master timing configuration.

pub const fn mstdat(self) -> Reg<Mstdat, RW>

Combined Master receiver and transmitter data register.

pub const fn slvctl(self) -> Reg<Slvctl, RW>

Slave control register.

pub const fn slvdat(self) -> Reg<Slvdat, RW>

Combined Slave receiver and transmitter data register.

pub const fn slvadr0(self) -> Reg<Slvadr0, RW>

Slave address register.

pub const fn slvadr1(self) -> Reg<Slvadr1, RW>

Slave address register.

pub const fn slvadr2(self) -> Reg<Slvadr2, RW>

Slave address register.

pub const fn slvadr3(self) -> Reg<Slvadr3, RW>

Slave address register.

pub const fn slvqual0(self) -> Reg<Slvqual0, RW>

Slave Qualification for address 0.

pub const fn monrxdat(self) -> Reg<Monrxdat, R>

Monitor receiver data register.

pub const fn id(self) -> Reg<Id, R>

Peripheral identification register.